componenttools.report_component_format_contributions_as_string
==============================================================

.. autofunction:: abjad.tools.componenttools.report_component_format_contributions_as_string.report_component_format_contributions_as_string
